# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from dicomrtai.proto import hello_world_pb2 as dicomrtai_dot_proto_dot_hello__world__pb2


class HelloWorldStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.talk = channel.unary_unary(
            "/HelloWorld/talk",
            request_serializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.SerializeToString,
            response_deserializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.FromString,
        )


class HelloWorldServicer(object):
    """Missing associated documentation comment in .proto file."""

    def talk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HelloWorldServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "talk": grpc.unary_unary_rpc_method_handler(
            servicer.talk,
            request_deserializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.FromString,
            response_serializer=dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "HelloWorld", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class HelloWorld(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def talk(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/HelloWorld/talk",
            dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.SerializeToString,
            dicomrtai_dot_proto_dot_hello__world__pb2.Greeting.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Greeting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONTENT_FIELD_NUMBER: builtins.int
    content: typing.Text = ...

    def __init__(self,
        *,
        content : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content"]) -> None: ...
global___Greeting = Greeting



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dicomrtai/proto/hello_world.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="dicomrtai/proto/hello_world.proto",
    package="",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n!dicomrtai/proto/hello_world.proto"\x1b\n\x08Greeting\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t2,\n\nHelloWorld\x12\x1e\n\x04talk\x12\t.Greeting\x1a\t.Greeting"\x00\x62\x06proto3',
)


_GREETING = _descriptor.Descriptor(
    name="Greeting",
    full_name="Greeting",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="content",
            full_name="Greeting.content",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=37,
    serialized_end=64,
)

DESCRIPTOR.message_types_by_name["Greeting"] = _GREETING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Greeting = _reflection.GeneratedProtocolMessageType(
    "Greeting",
    (_message.Message,),
    {
        "DESCRIPTOR": _GREETING,
        "__module__": "dicomrtai.proto.hello_world_pb2"
        # @@protoc_insertion_point(class_scope:Greeting)
    },
)
_sym_db.RegisterMessage(Greeting)


_HELLOWORLD = _descriptor.ServiceDescriptor(
    name="HelloWorld",
    full_name="HelloWorld",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=66,
    serialized_end=110,
    methods=[
        _descriptor.MethodDescriptor(
            name="talk",
            full_name="HelloWorld.talk",
            index=0,
            containing_service=None,
            input_type=_GREETING,
            output_type=_GREETING,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_HELLOWORLD)

DESCRIPTOR.services_by_name["HelloWorld"] = _HELLOWORLD

# @@protoc_insertion_point(module_scope)
